@@ -6,7 +6,7 @@ The module is generated using the `SWIG <https://www.swig.org>`_ interface gener
 
 pyAgrum includes :
   * API documentation <https://pyagrum.readthedocs.io>,
-  * examples as `notebooks <http://www-desir.lip6.fr/~phw/aGrUM/docs/last/notebooks/01-tutorial.ipynb.html>`_,
+  * examples as `notebooks <http://www-desir.lip6.fr/~phw/aGrUM/docs/last/notebooks/Tutorial.ipynb.html>`_,
   * a `website <http://agrum.org>`_.
 """
 
@@ -27,7 +27,7 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.19.0'
+__version__ = '0.20.2'
 __license__ = __doc__
 __project_url__ = 'http://agrum.org'
 
@@ -133,7 +133,7 @@ def about():
   about() for pyAgrum
 
   """
-  print("pyAgrum version {0}".format('0.19.0'))
+  print("pyAgrum version {0}".format('0.20.2'))
   print("(c) 2015-2020 Pierre-Henri Wuillemin, Christophe Gonzales, Lionel Torti")
   print("""
     This is free software; see the source code for copying conditions.
